Struct arma_rs::context::Context

source ·
pub struct Context { /* private fields */ }
Contains information about the current execution context

Implementations

source

impl Context

source

pub const fn global(&self) -> &GlobalContext

Global context

source

pub const fn group(&self) -> &GroupContext

Group context, is equal to GlobalContext if the call is from the global scope.

source

pub const fn caller(&self) -> &Caller

Player that called the extension. Can be Caller::Unknown when the player’s steamID64 is unavailable

Note

Unlike https://community.bistudio.com/wiki/getPlayerUID Caller::Steam isn’t limited to multiplayer.

source

pub const fn source(&self) -> &Source

Source from where the extension was called.

source

pub const fn mission(&self) -> &Mission

Current mission’s name.

Note

Can result in Mission::None in missions made prior to Arma v2.02.

source

pub const fn server(&self) -> &Server

Current server’s name

source

pub const fn buffer_len(&self) -> usize

Returns the length in bytes of the output buffer. This is the maximum size of the data that can be returned by the extension.

source

pub fn callback_data<V>( &self, name: &str, func: &str, data: V ) -> Result<(), CallbackError>where V: IntoArma,

source

pub fn callback_null(&self, name: &str, func: &str) -> Result<(), CallbackError>