Enum arma_rs::Result

source ·
pub enum Result<T, E> {
    Ok(T),
    Err(E),
    Continue,
    Timeout,
}
Result of an event handler

Variants



Ok(T)

an event has been handled and the handler is done, the value of T is the return value of the event handler



Err(E)

the handler has encountered an error, the value of T is the return value of the event handler



Continue

an event is handled but the handler is not done and should receive another event



Timeout

the handler reached the specified timeout

Implementations

Returns true if the result is an ok result

Returns true if the result is an error

Returns true if the result is a continue result

Returns true if the result is a timeout result