Enum arma_rs::Value

source ·
pub enum Value {
    Null,
    Number(f64),
    Array(Vec<Value>),
    Boolean(bool),
    String(String),
}
A value that can be converted to and from Arma types.

Variants



Null

Arma’s nil value. Represented as null



Number(f64)

Arma’s number value.



Array(Vec<Value>)

Arma’s array value. Represented as [...]



Boolean(bool)

Arma’s boolean value. Represented as true or false



String(String)

Arma’s string value. Represented as "..."

Note: Arma escapes quotes with two double quotes. This conversation will remove one step of escaping. Example: "My name is ""John""." will become My name is "John".

Implementations

source

impl Value

source

pub const fn as_null(&self) -> Option<()>

Returns an Option representing if the value is null

source

pub const fn is_null(&self) -> bool

Checks if the value is a null variant

source

pub const fn as_f64(&self) -> Option<f64>

Returns an Option representing if the value is a number

source

pub const fn is_number(&self) -> bool

Checks if the value is a number

source

pub const fn as_vec(&self) -> Option<&Vec<Self>>

Returns an Option representing if the value is an array

source

pub const fn is_array(&self) -> bool

Checks if the value is an array

source

pub const fn as_bool(&self) -> Option<bool>

Returns an Option representing if the value is a boolean

source

pub const fn is_boolean(&self) -> bool

Checks if the value is a boolean

source

pub fn as_str(&self) -> Option<&str>

Returns an Option representing if the value is a string

source

pub fn is_string(&self) -> bool

Checks if the value is a string

source

pub fn is_empty(&self) -> bool

Checks if the value is empty