Loadout

Struct Loadout 

pub struct Loadout(/* private fields */);
Arma Unit Loadout Array

Implementations

Source

impl Loadout

pub const fn primary(&self) -> &Weapon

Get the primary weapon

pub fn primary_mut(&mut self) -> &mut Weapon

Get the primary weapon mutably

pub fn set_primary(&mut self, primary: Weapon)

Set the primary weapon

pub const fn secondary(&self) -> &Weapon

Get the secondary weapon (launcher)

pub fn secondary_mut(&mut self) -> &mut Weapon

Get the secondary weapon (launcher) mutably

pub fn set_secondary(&mut self, secondary: Weapon)

Set the secondary weapon (launcher)

pub const fn handgun(&self) -> &Weapon

Get the handgun weapon

pub fn handgun_mut(&mut self) -> &mut Weapon

Get the handgun weapon mutably

pub fn set_handgun(&mut self, handgun: Weapon)

Set the handgun weapon

pub const fn uniform(&self) -> &Container

Get the uniform

pub fn uniform_mut(&mut self) -> &mut Container

Get the uniform mutably

pub fn set_uniform(&mut self, uniform: Container)

Set the uniform

pub const fn vest(&self) -> &Container

Get the vest

pub fn vest_mut(&mut self) -> &mut Container

Get the vest mutably

pub fn set_vest(&mut self, vest: Container)

Set the vest

pub const fn backpack(&self) -> &Container

Get the backpack

pub fn backpack_mut(&mut self) -> &mut Container

Get the backpack mutably

pub fn set_backpack(&mut self, backpack: Container)

Set the backpack

pub fn headgear(&self) -> &str

The class name of the current headgear

pub fn set_headgear(&mut self, headgear: String)

Set the class name of the current headgear

pub fn goggles(&self) -> &str

The class name of the current goggles / facewear

pub fn set_goggles(&mut self, goggles: String)

Set the class name of the current goggles / facewear

pub const fn binoculars(&self) -> &Weapon

Get the binocular

pub fn binoculars_mut(&mut self) -> &mut Weapon

Get the binocular mutably

pub fn set_binoculars(&mut self, binoculars: Weapon)

Set the binocular

pub const fn assigned_items(&self) -> &AssignedItems

Get the assigned items

pub fn assigned_items_mut(&mut self) -> &mut AssignedItems

Get the assigned items mutably

pub fn set_assigned_items(&mut self, assigned_items: AssignedItems)

Set the assigned items

pub fn cba_extended(&self) -> &CBAExtended

Get the CBA Extended Loadout Array

pub fn classes(&self) -> HashMap<String, u32>

Get a map of all items in the loadout and their quantities