Weapon

Struct Weapon 

pub struct Weapon(/* private fields */);
A primary, secondary, or handgun weapon

Implementations

Source

impl Weapon

pub fn new(class: String) -> Self

Create a new weapon

pub const fn exists(&self) -> bool

The weapon slot is occupied

pub fn class(&self) -> Option<&str>

The class name of the weapon

pub fn set_class(&mut self, class: String)

Set the class name of the weapon

pub fn suppressor(&self) -> Option<&str>

The class name of the attached suppressor

pub fn set_suppressor(&mut self, suppressor: String) -> bool

Set the class name of the attached suppressor Returns true if the suppressor was set, false if the weapon was not initialized

pub fn pointer(&self) -> Option<&str>

The class name of the attached pointer

pub fn set_pointer(&mut self, pointer: String) -> bool

Set the class name of the attached pointer Returns true if the pointer was set, false if the weapon was not initialized

pub fn optic(&self) -> Option<&str>

The class name of the attached optic

pub fn set_optic(&mut self, optic: String) -> bool

Set the class name of the attached optic Returns true if the optic was set, false if the weapon was not initialized

pub fn primary_magazine(&self) -> Option<&Magazine>

Get the inserted primary magazine

pub fn primary_magazine_mut(&mut self) -> Option<&mut Magazine>

Get the inserted primary magazine mutably

pub fn set_primary_magazine(&mut self, primary: Magazine) -> bool

Set the inserted primary magazine Returns true if the primary magazine was set, false if the weapon was not initialized

pub fn secondary_magazine(&self) -> Option<&Magazine>

Get the inserted secondary magazine

pub fn secondary_magazine_mut(&mut self) -> Option<&mut Magazine>

Get the inserted secondary magazine mutably

pub fn set_secondary_magazine(&mut self, secondary: Magazine) -> bool

Set the inserted secondary magazine Returns true if the secondary magazine was set, false if the weapon was not initialized

pub fn bipod(&self) -> Option<&str>

The class name of the attached bipod

pub fn set_bipod(&mut self, bipod: String) -> bool

Set the class name of the attached bipod Returns true if the bipod was set, false if the weapon was not initialized

pub fn classes(&self) -> Vec<&str>

Get all classes used on the weapon, including the weapon itself