pub struct Context { /* private fields */ }Expand description
Contains information about the current execution context
Implementations
sourceimpl Context
impl Context
sourcepub const fn buffer_len(&self) -> usize
pub const fn buffer_len(&self) -> usize
Returns the length in bytes of the output buffer. This is the maximum size of the data that can be returned by the extension.
sourcepub fn callback<V>(&self, name: &str, func: &str, data: Option<V>)where
V: IntoArma,
👎Deprecated since 1.8.0: Use callback_data instead. This function may be removed in future versions.
pub fn callback<V>(&self, name: &str, func: &str, data: Option<V>)where
V: IntoArma,
callback_data instead. This function may be removed in future versions.Sends a callback with data into Arma https://community.bistudio.com/wiki/Arma_3:_Mission_Event_Handlers#ExtensionCallback
sourcepub fn callback_data<V>(&self, name: &str, func: &str, data: V)where
V: IntoArma,
pub fn callback_data<V>(&self, name: &str, func: &str, data: V)where
V: IntoArma,
Sends a callback with data into Arma https://community.bistudio.com/wiki/Arma_3:_Mission_Event_Handlers#ExtensionCallback
sourcepub fn callback_null(&self, name: &str, func: &str)
pub fn callback_null(&self, name: &str, func: &str)
Sends a callback without data into Arma https://community.bistudio.com/wiki/Arma_3:_Mission_Event_Handlers#ExtensionCallback