pub enum Result<T, E> {
Ok(T),
Err(E),
Continue,
Timeout,
}Expand description
Result of an event handler
Variants
Ok(T)
an event has been handled and the handler is done, the value of T is the return value of the event handler
Err(E)
the handler has encountered an error, the value of T is the return value of the event handler
Continue
an event is handled but the handler is not done and should receive another event
Timeout
the handler reached the specified timeout
Implementations
sourceimpl<T, E> Result<T, E>
impl<T, E> Result<T, E>
sourcepub fn is_continue(&self) -> bool
pub fn is_continue(&self) -> bool
Returns true if the result is a continue result
sourcepub fn is_timeout(&self) -> bool
pub fn is_timeout(&self) -> bool
Returns true if the result is a timeout result