Enum arma_rs::Value[][src]

pub enum Value {
    Null,
    Number(f64),
    Array(Vec<Value>),
    Boolean(bool),
    String(String),
}
A value that can be converted to and from Arma types.

Variants

Null

Arma’s nil value. Represented as null

Number(f64)

Tuple Fields

0: f64

Arma’s number value.

Array(Vec<Value>)

Tuple Fields

0: Vec<Value>

Arma’s array value. Represented as [...]

Boolean(bool)

Tuple Fields

0: bool

Arma’s boolean value. Represented as true or false

String(String)

Tuple Fields

0: String

Arma’s string value. Represented as "..."

Note: Arma escapes quotes with two double quotes. This conversation will remove one step of escaping. Example: "My name is ""John""." will become My name is "John".

Implementations

Returns an Option representing if the value is null

Checks if the value is a null variant

Returns an Option representing if the value is a number

Checks if the value is a number

Returns an Option representing if the value is an array

Checks if the value is an array

Returns an Option representing if the value is a boolean

Checks if the value is a boolean

Returns an Option representing if the value is a string

Checks if the value is a string

Checks if the value is empty