Enum arma_rs::Value [−][src]
A value that can be converted to and from Arma types.
Variants
Null
Arma’s nil value.
Represented as null
Number(f64)
Tuple Fields
0: f64Arma’s number value.
Array(Vec<Value>)
Arma’s array value.
Represented as [...]
Boolean(bool)
Tuple Fields
0: boolArma’s boolean value.
Represented as true or false
String(String)
Tuple Fields
0: StringArma’s string value.
Represented as "..."
Note: Arma escapes quotes with two double quotes.
This conversation will remove one step of escaping.
Example: "My name is ""John""." will become My name is "John".
Implementations
Returns an Option representing if the value is a number
Returns an Option representing if the value is an array
Returns an Option representing if the value is a boolean
Checks if the value is a boolean