pub struct Context { /* private fields */ }
Contains information about the current execution context

Implementations

Returns the length in bytes of the output buffer. This is the maximum size of the data that can be returned by the extension.

👎Deprecated since 1.8.0:

Use callback_data instead. This function may be removed in future versions.