pub struct Context { /* private fields */ }Expand description
Contains information about the current execution context
Implementations
sourceimpl Context
impl Context
sourcepub const fn buffer_len(&self) -> usize
pub const fn buffer_len(&self) -> usize
Returns the length in bytes of the output buffer. This is the maximum size of the data that can be returned by the extension.