pub struct Context { /* private fields */ }
Contains information about the current execution context
Returns the length in bits of the output buffer.
This is the maximum size of the data that can be returned by the extension.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.