Struct arma_rs::Context [−][src]
pub struct Context { /* fields omitted */ }Expand description
Contains information about the current execution context
Implementations
Returns the length in bits of the output buffer. This is the maximum size of the data that can be returned by the extension.