Struct arma_rs::Context [−][src]
pub struct Context { /* fields omitted */ }Implementations
Returns the length of the output buffer. This is the maximum size of the data that can be returned by the extension.
pub struct Context { /* fields omitted */ }Returns the length of the output buffer. This is the maximum size of the data that can be returned by the extension.