Struct arma_rs::Extension [−][src]
pub struct Extension { /* fields omitted */ }Expand description
Contains all the information about your extension This is used by the generated code to interface with Arma
Implementations
Creates a new extension.
Returns if the extension can be called without any arguments. Example:
"my_ext" callExtension "my_func"Called by generated code, do not call directly.
Called by generated code, do not call directly.
Safety
This function is unsafe because it interacts with the C API.
Called by generated code, do not call directly.